@@ -7,7 +7,6 @@
  * be passed to the template file.                                         *
  *                                                                         *
  ***************************************************************************/
-/* $XFree86: xc/config/imake/imake.c,v 3.64 2003/03/26 20:43:47 tsi Exp $ */
 
 /*
  *
@@ -191,7 +190,7 @@ in this Software without prior written authorization from The Open Group.
 #include <sys/stat.h>
 #ifndef X_NOT_POSIX
 # ifdef _POSIX_SOURCE
-#  ifdef SCO325
+#  ifdef __SCO__
 #   include <sys/procset.h>
 #   include <sys/siginfo.h>
 #  endif
@@ -1262,10 +1261,10 @@ get_gcc_version(FILE *inFile, char *name)
 #endif
     {
 #if __GNUC__ > 1
-	fprintf (inFile, "#define HasGcc2 1\n");
-# if __GNUC__ > 2
-	fprintf (inFile, "#define HasGcc3 1\n");
-# endif
+	int v;
+
+	for (v = 2;  v <= __GNUC__;  v++)
+	    fprintf (inFile, "#define HasGcc%d 1\n", v);
 #endif
 	fprintf (inFile, "#define GccMajorVersion %d\n", __GNUC__);
 	fprintf (inFile, "#define GccMinorVersion %d\n", __GNUC_MINOR__);
@@ -1291,7 +1290,8 @@ get_gcc(char *cmd)
 # endif
 	"/usr/local/bin/gcc",
 	"/opt/gnu/bin/gcc",
-	"/usr/pkg/bin/gcc"
+	"/usr/pkg/bin/gcc",
+	"/usr/bin/gcc"
     };
 
 #ifdef CROSSCOMPILE
@@ -1721,6 +1721,15 @@ CleanCppInput(char *imakefile)
 				tmpImakefile);
 			}
 #endif
+			/*
+			 * mktemp/mkstemp can generate a filename that makes
+			 * '#include INCLUDE_IMAKEFILE' croak.  So spit out a
+			 * nice fat warning about the need to generate such
+			 * filenames in the first place.
+			 */
+			fprintf(stderr,
+				"%s:  warning:  %s contains invalid %s input."
+				"  Please fix!\n", program, imakefile, cpp);
 		    }
 		    writetmpfile(outFile, punwritten, pbuf-punwritten,
 				 tmpImakefile);
@@ -1907,7 +1916,7 @@ ReadLine(FILE *tmpfd, char *tmpfname)
 		initialized = TRUE;
 	    fprintf (tmpfd, "# Makefile generated by imake - do not edit!\n");
 	    fprintf (tmpfd, "# %s\n",
-		"$Xorg: imake.c,v 1.6 2001/02/09 02:03:15 xorgcvs Exp $");
+		"$XFree86: xc/config/imake/imake.c,v 3.68 2006/01/09 14:56:14 dawes Exp $");
 	}
 
 	for (p1 = pline; p1 < end; p1++) {
