@@ -19,7 +19,7 @@
  * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  * PERFORMANCE OF THIS SOFTWARE.
  */
-/* $XFree86: xc/extras/fontconfig/src/fccfg.c,v 1.2 2003/06/04 16:29:39 dawes Exp $ */
+/* $XFree86: xc/extras/fontconfig/src/fccfg.c,v 1.4 2006/03/27 01:32:46 dawes Exp $ */
 
 #include "fcint.h"
 
@@ -675,6 +675,7 @@ FcConfigEvaluate (FcPattern *p, FcExpr *e)
 	r = FcPatternGet (p, e->u.field, 0, &v);
 	if (r != FcResultMatch)
 	    v.type = FcTypeVoid;
+	v = FcValueSave (v);
 	break;
     case FcOpConst:
 	if (FcNameConstant (e->u.constant, &v.u.i))
@@ -1382,10 +1383,11 @@ FcConfigFilename (const FcChar8 *url)
     file = 0;
     switch (*url) {
     case '~':
-	dir = (FcChar8 *) getenv ("HOME");
-	if (dir)
+	dir = FcGetHomeDir ();
+	if (dir) {
 	    file = FcConfigFileExists (dir, url + 1);
-	else
+	    FcStrFree (dir);
+	} else
 	    file = 0;
 	break;
     case '/':
